#[non_exhaustive]pub struct CollectingEventHandler { /* private fields */ }Expand description
Event handler that collects text into a buffer.
This handler is useful when you need to capture the full response while also allowing streaming events to be processed.
Example
use gba_core::event::CollectingEventHandler;
let mut handler = CollectingEventHandler::new();
// Use with streaming...
let collected_text = handler.text();Implementations
Sourceimpl CollectingEventHandler
impl CollectingEventHandler
Sourcepub fn tools_used(&self) -> &[String]
pub fn tools_used(&self) -> &[String]
Get the list of tools that were used.